@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_001;
 
-use version; our $VERSION = 'v0.6.0';
+use version; our $VERSION = 'v0.6.1';
 
 1;
 __END__
@@ -24,7 +24,7 @@ Then if one worker stops with any trouble, remaining workers will take after its
 
 =head1 DOCUMENTATION
 
-Full documentation is available on L<http://key-amb.github.io/App-Koyomi-Doc/>.
+Full documentation is available on L<http://progrhyme.github.io/App-Koyomi-Doc/>.
 
 =head1 SEE ALSO
 
@@ -35,11 +35,11 @@ L<App::Koyomi::CLI>
 
 =head1 AUTHORS
 
-YASUTAKE Kiyoshi E<lt>yasutake.kiyoshi@gmail.comE<gt>
+IKEDA Kiyoshi E<lt>progrhyme@gmail.comE<gt>
 
 =head1 LICENSE
 
-Copyright (C) 2015 YASUTAKE Kiyoshi.
+Copyright (C) 2015-2017 IKEDA Kiyoshi.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.  That means either (a) the GNU General Public
