@@ -5,7 +5,7 @@ use warnings;
 use 5.010_001;
 use Carp qw(croak);
 
-use version; our $VERSION = 'v0.6.0';
+use version; our $VERSION = 'v0.6.1';
 
 sub instance     { croak 'Must implement in child class!'; }
 sub gets         { croak 'Must implement in child class!'; }
@@ -77,11 +77,11 @@ L<App::Koyomi::Job>
 
 =head1 AUTHORS
 
-YASUTAKE Kiyoshi E<lt>yasutake.kiyoshi@gmail.comE<gt>
+IKEDA Kiyoshi E<lt>progrhyme@gmail.comE<gt>
 
 =head1 LICENSE
 
-Copyright (C) 2015 YASUTAKE Kiyoshi.
+Copyright (C) 2015-2017 IKEDA Kiyoshi.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.  That means either (a) the GNU General Public
