@@ -8,7 +8,7 @@ use Smart::Args;
 use App::Koyomi::Job;
 use App::Koyomi::JobTime::Formatter qw(time2str);
 
-use version; our $VERSION = 'v0.6.0';
+use version; our $VERSION = 'v0.6.1';
 
 # Accessor for job_times.columns
 {
@@ -59,11 +59,11 @@ L<Teng::Row>
 
 =head1 AUTHORS
 
-YASUTAKE Kiyoshi E<lt>yasutake.kiyoshi@gmail.comE<gt>
+IKEDA Kiyoshi E<lt>progrhyme@gmail.comE<gt>
 
 =head1 LICENSE
 
-Copyright (C) 2015 YASUTAKE Kiyoshi.
+Copyright (C) 2015-2017 IKEDA Kiyoshi.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.  That means either (a) the GNU General Public
