@@ -13,7 +13,7 @@ use Smart::Args;
 
 use App::Koyomi::Semaphore;
 
-use version; our $VERSION = 'v0.6.0';
+use version; our $VERSION = 'v0.6.1';
 
 our @JOB_FIELDS  = qw/id user command memo created_on updated_at/;
 our @TIME_FIELDS = qw/id job_id year month day hour minute weekday created_on updated_at/;
@@ -152,11 +152,11 @@ Execute job.
 
 =head1 AUTHORS
 
-YASUTAKE Kiyoshi E<lt>yasutake.kiyoshi@gmail.comE<gt>
+IKEDA Kiyoshi E<lt>progrhyme@gmail.comE<gt>
 
 =head1 LICENSE
 
-Copyright (C) 2015 YASUTAKE Kiyoshi.
+Copyright (C) 2015-2017 IKEDA Kiyoshi.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.  That means either (a) the GNU General Public
